@@ -1,4 +1,5 @@
 from django import forms
+from writingfield import FullScreenTextarea
 from ccnews.models import Article
 
 
@@ -6,6 +7,10 @@ class ArticleAdminForm(forms.ModelForm):
 
     class Meta:
         model = Article
+        widgets = {
+            'content': FullScreenTextarea()
+        }
+
 
     class Media:
         css = {
