@@ -49,7 +49,9 @@ class Article(models.Model):
             'month': self.created.month,
             'slug': self.slug})
 
-
+    @property
+    def description(self):
+        return u'%s' % self.content_rendered[:100]
 
 class ArticleImage(models.Model):
     article = models.ForeignKey(Article)
